@@ -40,6 +40,10 @@
 /*	VSTRING	*vp;
 /*	ssize_t	len;
 /*
+/*	VSTRING	*vstring_set_payload_size(vp, len)
+/*	VSTRING	*vp;
+/*	ssize_t	len;
+/*
 /*	void	VSTRING_RESET(vp)
 /*	VSTRING	*vp;
 /*
@@ -180,6 +184,15 @@
 /*	The operation has no effect when the string is shorter.
 /*	The string is not null-terminated.
 /*
+/*	vstring_set_payload_size() sets the number of 'used' bytes
+/*	in the named buffer's metadata. This determines the buffer
+/*	write position and the VSTRING_LEN() result. The payload
+/*	size must be within the closed range [0, number of allocated
+/*	bytes]. The typical usage is to request buffer space with
+/*	VSTRING_SPACE(), to use some non-VSTRING operations to write
+/*	to the buffer, and to call vstring_set_payload_size() to
+/*	update buffer metadata, perhaps followed by VSTRING_TERMINATE().
+/*
 /*	VSTRING_RESET() is a macro that resets the write position of its
 /*	string argument to the very beginning. Note that VSTRING_RESET()
 /*	is an unsafe macro that evaluates some arguments more than once.
@@ -283,6 +296,8 @@
 
 /* Utility library. */
 
+#define VSTRING_INTERNAL
+
 #include "mymalloc.h"
 #include "msg.h"
 #include "vbuf_print.h"
@@ -324,7 +339,7 @@ static void vstring_extend(VBUF *bp, ssize_t incr)
 
 static int vstring_buf_get_ready(VBUF *unused_buf)
 {
-    msg_panic("vstring_buf_get: write-only buffer");
+    return (VBUF_EOF);			/* be VSTREAM-friendly */
 }
 
 /* vstring_buf_put_ready - vbuf callback for write buffer full condition */
@@ -371,7 +386,6 @@ VSTRING *vstring_alloc(ssize_t len)
     vp->vbuf.get_ready = vstring_buf_get_ready;
     vp->vbuf.put_ready = vstring_buf_put_ready;
     vp->vbuf.space = vstring_buf_space;
-    vp->maxlen = 0;
     return (vp);
 }
 
@@ -397,11 +411,6 @@ void    vstring_ctl(VSTRING *vp,...)
 	switch (code) {
 	default:
 	    msg_panic("vstring_ctl: unknown code: %d", code);
-	case VSTRING_CTL_MAXLEN:
-	    vp->maxlen = va_arg(ap, ssize_t);
-	    if (vp->maxlen < 0)
-		msg_panic("vstring_ctl: bad max length %ld", (long) vp->maxlen);
-	    break;
 	case VSTRING_CTL_EXACT:
 	    vp->vbuf.flags |= VSTRING_FLAG_EXACT;
 	    break;
@@ -426,6 +435,16 @@ VSTRING *vstring_truncate(VSTRING *vp, ssize_t len)
     return (vp);
 }
 
+/* vstring_set_payload_size - public version of VSTRING_AT_OFFSET */
+
+VSTRING *vstring_set_payload_size(VSTRING *vp, ssize_t len)
+{
+    if (len < 0 || len > vp->vbuf.len)
+	msg_panic("vstring_set_payload_size: invalid offset: %ld", (long) len);
+    VSTRING_AT_OFFSET(vp, len);
+    return (vp);
+}
+
 /* vstring_strcpy - copy string */
 
 VSTRING *vstring_strcpy(VSTRING *vp, const char *src)
@@ -593,7 +612,6 @@ VSTRING *vstring_import(char *str)
     vp->vbuf.get_ready = vstring_buf_get_ready;
     vp->vbuf.put_ready = vstring_buf_put_ready;
     vp->vbuf.space = vstring_buf_space;
-    vp->maxlen = 0;
     return (vp);
 }
 
